<?php

namespace Slovocast\Infrastructure\Application;

use Slovocast\Infrastructure\Application\DefinitionInterface;
use Slovocast\Infrastructure\Api\User\UserSessionManagerInterface;
use Slovocast\Infrastructure\User\UserSessionManager;
use Slovocast\Middleware\SessionMiddleware;
use Odan\Session\PhpSession;
use Odan\Session\SessionInterface;
use Odan\Session\SessionManagerInterface;
use Psr\Container\ContainerInterface;
use Psr\Log\LoggerInterface;

class SessionDefintion implements DefinitionInterface
{
    public function define(): array
    {
        return [
            SessionManagerInterface::class => function (ContainerInterface $container) {
                return $container->get(SessionInterface::class);
            },
            SessionInterface::class => function (ContainerInterface $container) {
                $options = $container->get('config')->get('session');
                return new PhpSession($options);
            },
            'session' => function (ContainerInterface $container) {
                return $container->get(SessionInterface::class);
            },
            SessionMiddleware::class => function (ContainerInterface $container) {
                return new SessionMiddleware(
                    $container->get(SessionManagerInterface::class),
                    $container->get(SessionInterface::class),
                    $container->get(LoggerInterface::class)
                );
            },
            UserSessionManagerInterface::class => function (ContainerInterface $container) {
                return new UserSessionManager($container->get(SessionInterface::class));
            },           
        ];
    }
}
